csep.core.forecasts.GriddedForecast.target\_event\_rates
========================================================

.. currentmodule:: csep.core.forecasts

.. automethod:: GriddedForecast.target_event_rates